#
# spec file for package kdumpid
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Begin compatibility cruft
#

%if 0%{!?have_zstd:1}
%if 0%{?sle_version} >= 152000
%define have_zstd 1
%else
%define have_zstd 0
%endif
%endif

#
# End compatibility cruft

#Url:

Name:           kdumpid
BuildRequires:  binutils-devel
BuildRequires:  libkdumpfile-devel
BuildRequires:  zlib-devel
Version:        1.5
Release:        1.1
Summary:        Utility to extract information from vmcores
License:        GPL-2.0-or-later
Group:          System/Kernel
URL:            http://sourceforge.net/p/kdumpid
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source:         %{name}-%{version}.tar.bz2

%description
Kdumpid extracts information such as type of dump, architecture
and kernel version from raw vmcores (Kernel memory dumps).

%prep
%setup
%autopatch -p1

chmod +x libs.sh

%build
make CUSTOM_CFLAGS="${CFLAGS:-%optflags}"

%install
export BINDIR=%{_bindir}
export MANDIR=%{_mandir}
%{?make_install} %{!?make_install:make install DESTDIR=$RPM_BUILD_ROOT}

%files
%defattr (-, root, root)
%{_bindir}/*
%{_mandir}/man1/*

%changelog
* Thu Jun 29 2023 Petr Tesařík <petr@tesarici.cz>
- Update to version 1.5
  * Fix crashes if a disassembler is not implemented.
  * Fix a couple of build issues.
- Patches moved to upstream:
  * kdumpid-Fix-build-for-binutils-2.40.patch
* Thu Apr 13 2023 Petr Tesařík <petr@tesarici.cz>
- kdumpid-Fix-build-for-binutils-2.40.patch: Fix build for
  binutils < 2.40.
* Thu Apr 13 2023 Petr Tesařík <petr@tesarici.cz>
- Update to version 1.4
  * Bugfix release
- Patches moved to upstream:
  * kdumpid-append_insn.patch
  * kdumpid-binutils-2.39-fix.patch
* Tue Aug 16 2022 Petr Tesařík <ptesarik@suse.com>
- Fix build with binutils-2.39:
  * kdumpid-append_insn.patch
  * kdumpid-binutils-2.39-fix.patch
* Tue Sep 22 2020 Petr Tesařík <ptesarik@suse.com>
- Update to version 1.3:
  * Switch to libkdumpfile-0.4.0
  * Update API to newer binutils (bsc#1197741).
* Mon May 15 2017 ptesarik@suse.com
- Update to version 1.2:
  * Switch to libkdumpfile-0.3.0
  * Handle converted z/Architecture VMDUMP files (bsc#883757).
* Mon Feb  1 2016 ptesarik@suse.com
- Update to version 1.1:
  * Support for libkdumpfile-0.2.0
- Patches moved to upstream:
  * kdumpid-libkdumpfile-libs.patch
  * kdumpid-x86_64-fix-NULL-arch-segv.patch
  * kdumpid-quit-on-libkdumpfile-failure.patch
  * kdumpid-fix-kdump_is_xen.patch
  * kdumpid-x86-out-of-bounds-disas.patch
* Tue Nov  4 2014 ptesarik@suse.cz
- kdumpid-fix-kdump_is_xen.patch: Fix wrong use of kdump_is_xen().
* Mon Nov  3 2014 ptesarik@suse.cz
- kdumpid-x86-out-of-bounds-disas.patch: x86: Prevent out-of-bounds
  reads in disas_at().
* Mon Nov  3 2014 ptesarik@suse.cz
- kdumpid-quit-on-libkdumpfile-failure.patch: Quit on libkdumpfile
  failure.
- kdumpid-x86_64-fix-NULL-arch-segv.patch Fix SEGV when checking
  x86_64 and arch is unknown.
* Mon Nov  3 2014 ptesarik@suse.cz
- kdumpid-libkdumpfile-libs.patch: Do not try to link additional
  libraries needed by libkdumpfile.
* Mon Nov  3 2014 ptesarik@suse.cz
- Update to version 1.0:
  * Include Xen version in the output
  * Backend split off to libkdumpfile
* Fri Apr  5 2013 ptesarik@suse.cz
- Update to version 0.92:
  o add a manual page
  o avoid a gcc warning
- Improve packaging (use RPM macros to set up destination paths).
* Fri Apr  5 2013 ptesarik@suse.cz
- Update to version 0.91 (another bug-fix release).
* Wed Nov  2 2011 ptesarik@suse.cz
- Update to version 0.90 (actually a bug-fix release).
* Tue Nov  1 2011 lchiquitto@suse.com
- Pull more fixes and improvements from the upstream repository:
  * Add support for ppc and ppc64.
  * Implement a --verbose flag.
  * Add RLE dump uncompression method (used in some LKCD dumps).
  * Add many LKCD fixes and improvements.
* Wed Oct 19 2011 lchiquitto@suse.com
- Update to version 0.9, which fixes some bugs and implements some
  new features:
  * Support /dev/mem and /dev/crash formats.
  * Support for big-endian LKCD dumps.
  * Preliminary support for s/390.
* Tue Oct 18 2011 lchiquitto@suse.com
- x86: Fix a segfault when disassembling invalid pages.
* Tue Oct 18 2011 lchiquitto@suse.com
- Update to current git snapshot (20111018): kdumpid is now able to
  correctly identify Xen dom0 dumps, among other improvements.
* Fri Oct 14 2011 lchiquitto@suse.com
- Import kdumpid.
